@@ -16,9 +16,10 @@
  ***************************************************************************/
 
 #include "entry.h"
-#include "file.h"
 
-#define max(a,b) ((a)>(b)?(a):(b))
+#include <typeinfo>
+
+#include "file.h"
 
 // FIXME: Check if using those constants in the program is really necessary
 // or can be replace by config files
@@ -122,7 +123,7 @@ Value &Entry::operator[](const QString &key)
     return QMap<QString, Value>::operator[](key);
 }
 
-const  Value Entry::operator[](const QString &key) const
+const Value Entry::operator[](const QString &key) const
 {
     const QString lcKey = key.toLower();
     for (Entry::ConstIterator it = constBegin(); it != constEnd(); ++it)
@@ -196,6 +197,9 @@ Entry *Entry::resolveCrossref(const Entry &original, const File *bibTeXfile)
         return result;
 
     const QString crossRef = PlainTextValue::text(original.value(ftCrossRef));
+    if (crossRef.isEmpty())
+        return result;
+
     const QSharedPointer<Entry> crossRefEntry = bibTeXfile->containsKey(crossRef, File::etEntry).dynamicCast<Entry>();
     if (!crossRefEntry.isNull()) {
         /// copy all fields from crossref'ed entry to new entry which do not (yet) exist in the new entry
@@ -244,3 +248,7 @@ QStringList Entry::authorsLastName() const
 {
     return authorsLastName(*this);
 }
+
+bool Entry::isEntry(const Element &other) {
+    return typeid(other) == typeid(Entry);
+}
