@@ -22,8 +22,8 @@
 #include <QIODevice>
 #include <QStringList>
 #include <QRegExp>
-#include <QSet>
 
+#include <KDebug>
 #include <KSharedConfig>
 #include <KConfigGroup>
 
@@ -61,18 +61,38 @@ public:
 
     FilePrivate(File */* UNUSED parent*/)
         : /* UNUSED p(parent),*/ validInvalidField(valid), config(KSharedConfig::openConfig(QLatin1String("kbibtexrc"))), configGroupName(QLatin1String("FileExporterBibTeX")), internalId(++internalIdCounter) {
+        kDebug() << "Creating File instance" << internalId;
         loadConfiguration();
     }
 
+    FilePrivate(const File &other, File */* UNUSED parent*/)
+        : /* UNUSED p(parent),*/ validInvalidField(valid), config(KSharedConfig::openConfig(QLatin1String("kbibtexrc"))), configGroupName(QLatin1String("FileExporterBibTeX")), internalId(++internalIdCounter) {
+        const bool isValid = checkValidity();
+        kDebug() << "Creating File instance" << internalId << "  Valid?" << isValid;
+
+        /// Copy properties from other File object
+        static const QStringList propertyKeys = QStringList() << File::Encoding << File::StringDelimiter << File::QuoteComment << File::KeywordCasing << File::NameFormatting << File::ProtectCasing << File::ListSeparator;
+        foreach(const QString &propertyKey, propertyKeys)
+            properties.insert(propertyKey, other.d->properties[propertyKey]);
+    }
+
     FilePrivate(File */* UNUSED parent*/, const File &other)
         : /* UNUSED p(parent),*/ validInvalidField(valid), config(KSharedConfig::openConfig(QLatin1String("kbibtexrc"))), configGroupName(QLatin1String("FileExporterBibTeX")), internalId(++internalIdCounter), properties(other.d->properties) {
+        kDebug() << "Creating File instance" << internalId;
         loadConfiguration();
     }
 
     ~FilePrivate() {
+        kDebug() << "Deleting File instance" << internalId;
         validInvalidField = invalid;
     }
 
+    FilePrivate &operator= (const FilePrivate &other) {
+        validInvalidField = other.validInvalidField;
+        properties = other.properties;
+        return *this;
+    }
+
     void loadConfiguration() {
         /// Load and set configuration as stored in settings
         KConfigGroup configGroup(config, configGroupName);
@@ -98,12 +118,22 @@ File::File()
     // nothing
 }
 
+File::File(const File &other)
+        : QList<QSharedPointer<Element> >(other), d(new FilePrivate(other, this)) {
+    /// nothing
+}
+
 File::~File()
 {
     Q_ASSERT_X(d->checkValidity(), "File::~File()", "This File object is not valid");
     delete d;
 }
 
+File &File::operator= (const File &other) {
+    d->operator =(*other.d);
+    return *this;
+}
+
 const QSharedPointer<Element> File::containsKey(const QString &key, ElementTypes elementTypes) const
 {
     Q_ASSERT_X(d->checkValidity(), "const QSharedPointer<Element> File::containsKey(const QString &key, ElementTypes elementTypes) const", "This File object is not valid");
