@@ -17,6 +17,8 @@
 
 #include "value.h"
 
+#include <typeinfo>
+
 #include <QSet>
 #include <QString>
 #include <QStringList>
@@ -97,6 +99,10 @@ bool Keyword::operator==(const ValueItem &other) const
         return false;
 }
 
+bool Keyword::isKeyword(const ValueItem &other) {
+    return typeid(other) == typeid(Keyword);
+}
+
 
 Person::Person(const QString &firstName, const QString &lastName, const QString &suffix)
         : m_firstName(firstName), m_lastName(lastName), m_suffix(suffix)
@@ -190,6 +196,10 @@ QString Person::transcribePersonName(const QString &formatting, const QString &f
     return result;
 }
 
+bool Person::isPerson(const ValueItem &other) {
+    return typeid(other) == typeid(Person);
+}
+
 
 const QRegExp MacroKey::validMacroKey = QRegExp("^[a-z][-.:/+_a-z0-9]*$|^[0-9]+$", Qt::CaseInsensitive);
 
@@ -245,6 +255,10 @@ bool MacroKey::operator==(const ValueItem &other) const
         return false;
 }
 
+bool MacroKey::isMacroKey(const ValueItem &other) {
+    return typeid(other) == typeid(MacroKey);
+}
+
 
 PlainText::PlainText(const PlainText &other)
         : m_text(other.text())
@@ -291,6 +305,10 @@ bool PlainText::operator==(const ValueItem &other) const
         return false;
 }
 
+bool PlainText::isPlainText(const ValueItem &other) {
+    return typeid(other) == typeid(PlainText);
+}
+
 
 bool VerbatimText::colorLabelPairsInitialized = false;
 QList<VerbatimText::ColorLabelPair> VerbatimText::colorLabelPairs = QList<VerbatimText::ColorLabelPair>();
@@ -370,11 +388,15 @@ bool VerbatimText::operator==(const ValueItem &other) const
         return false;
 }
 
+bool VerbatimText::isVerbatimText(const ValueItem &other) {
+    return typeid(other) == typeid(VerbatimText);
+}
+
 
 Value::Value()
         : QVector<QSharedPointer<ValueItem> >()
 {
-    // nothing
+    /// nothing
 }
 
 Value::Value(const Value &other)
@@ -569,7 +591,7 @@ QString PlainTextValue::text(const ValueItem &valueItem, ValueItemType &vit)
     /// clean up result string
     const int len = result.length();
     int j = 0;
-    static const QChar cbo = QLatin1Char('{'), cbc = QLatin1Char('}'), bs = QLatin1Char('\\'), mns = QLatin1Char('-'), comma = QLatin1Char(','), thinspace = QChar(0x2009);
+    static const QChar cbo = QLatin1Char('{'), cbc = QLatin1Char('}'), bs = QLatin1Char('\\'), mns = QLatin1Char('-'), comma = QLatin1Char(','), thinspace = QChar(0x2009), tilde = QLatin1Char('~'), nobreakspace = QChar(0x00a0);
     for (int i = 0; i < len; ++i) {
         if ((result[i] == cbo || result[i] == cbc) && (i < 1 || result[i - 1] != bs)) {
             /// hop over curly brackets
@@ -580,6 +602,10 @@ QString PlainTextValue::text(const ValueItem &valueItem, ValueItemType &vit)
             /// place '\,' with a thin space
             result[j] = thinspace;
             ++i; ++j;
+        } else if (result[i] == tilde && (i < 1 || result[i - 1] != bs))  {
+            /// place '~' with a non-breaking space
+            result[j] = nobreakspace;
+            ++j;
         } else {
             if (i > j) {
                 /// move individual characters forward in result string
