@@ -17,8 +17,6 @@
 
 #include "elementwidgets.h"
 
-#include <typeinfo>
-
 #include <QLayout>
 #include <QBuffer>
 #include <QLabel>
@@ -183,7 +181,7 @@ void EntryConfiguredWidget::setFile(const File *file)
 
 bool EntryConfiguredWidget::canEdit(const Element *element)
 {
-    return typeid(*element) == typeid(Entry);
+    return Entry::isEntry(*element);
 }
 
 void EntryConfiguredWidget::createGUI()
@@ -234,7 +232,7 @@ void EntryConfiguredWidget::layoutGUI(bool forceVisible, const QString &entryTyp
     QStringList visibleItems;
     if (!forceVisible && !entryType.isEmpty()) {
         const QString entryTypeLc = entryType.toLower();
-        BibTeXEntries *be = BibTeXEntries::self();
+        const BibTeXEntries *be = BibTeXEntries::self();
         for (BibTeXEntries::ConstIterator bit = be->constBegin(); bit != be->constEnd(); ++bit) {
             if (entryTypeLc == bit->upperCamelCase.toLower() || entryTypeLc == bit->upperCamelCaseAlt.toLower()) {
                 /// this ugly conversion is necessary because we have a "^" (xor) and "|" (and/or)
@@ -337,7 +335,7 @@ bool ReferenceWidget::apply(QSharedPointer<Element> element) const
     bool result = false;
     QSharedPointer<Entry> entry = element.dynamicCast<Entry>();
     if (!entry.isNull()) {
-        BibTeXEntries *be = BibTeXEntries::self();
+        const BibTeXEntries *be = BibTeXEntries::self();
         QString type;
         if (entryType->currentIndex() < 0 || entryType->lineEdit()->isModified())
             type = be->format(entryType->lineEdit()->text(), KBibTeX::cUpperCamelCase);
@@ -370,7 +368,7 @@ bool ReferenceWidget::reset(QSharedPointer<const Element> element)
     if (!entry.isNull()) {
         entryType->setEnabled(!isReadOnly);
         buttonSuggestId->setEnabled(!isReadOnly);
-        BibTeXEntries *be = BibTeXEntries::self();
+        const BibTeXEntries *be = BibTeXEntries::self();
         QString type = be->format(entry->type(), KBibTeX::cUpperCamelCase);
         int index = entryType->findData(type);
         if (index == -1) {
@@ -432,7 +430,7 @@ KIcon ReferenceWidget::icon()
 
 bool ReferenceWidget::canEdit(const Element *element)
 {
-    return typeid(*element) == typeid(Entry) || typeid(*element) == typeid(Macro);
+    return Entry::isEntry(*element) || Macro::isMacro(*element);
 }
 
 void ReferenceWidget::setOriginalElement(const QSharedPointer<Element> &orig)
@@ -469,7 +467,7 @@ void ReferenceWidget::createGUI()
     layout->addWidget(label);
     layout->addWidget(entryId);
 
-    BibTeXEntries *be = BibTeXEntries::self();
+    const BibTeXEntries *be = BibTeXEntries::self();
     for (BibTeXEntries::ConstIterator it = be->constBegin(); it != be->constEnd(); ++it)
         entryType->addItem(it->label, it->upperCamelCase);
     /// Sort the combo box locale-aware. Thus we need a SortFilterProxyModel
@@ -706,7 +704,7 @@ void FilesWidget::setFile(const File *file)
 
 bool FilesWidget::canEdit(const Element *element)
 {
-    return typeid(*element) == typeid(Entry);
+    return Entry::isEntry(*element);
 }
 
 const QStringList FilesWidget::keyStart = QStringList() << Entry::ftUrl << QLatin1String("postscript") << Entry::ftLocalFile << Entry::ftDOI << Entry::ftFile << QLatin1String("ee") << QLatin1String("biburl");
@@ -779,7 +777,7 @@ KIcon OtherFieldsWidget::icon()
 
 bool OtherFieldsWidget::canEdit(const Element *element)
 {
-    return typeid(*element) == typeid(Entry);
+    return Entry::isEntry(*element);
 }
 
 void OtherFieldsWidget::listElementExecuted(QTreeWidgetItem *item, int column)
@@ -1001,7 +999,7 @@ KIcon MacroWidget::icon()
 
 bool MacroWidget::canEdit(const Element *element)
 {
-    return typeid(*element) == typeid(Macro);
+    return Macro::isMacro(*element);
 }
 
 void MacroWidget::createGUI()
@@ -1066,7 +1064,7 @@ KIcon PreambleWidget::icon()
 
 bool PreambleWidget::canEdit(const Element *element)
 {
-    return typeid(*element) == typeid(Preamble);
+    return Preamble::isPreamble(*element);
 }
 
 void PreambleWidget::createGUI()
@@ -1097,7 +1095,7 @@ protected:
         FileImporterBibTeX importer;
         FileExporterBibTeX exporter;
         const File *file = importer.fromString(event->mimeData()->text());
-        if (file->count() == 1)
+        if (file != NULL && file->count() == 1)
             document()->setPlainText(exporter.toString(file->first(), file));
         else
             KTextEdit::dropEvent(event);
