@@ -36,7 +36,7 @@
 #include <KPushButton>
 #include <KFileDialog>
 #include <KInputDialog>
-#include <KIO/NetAccess>
+#include <KIO/CopyJob>
 #include <KGlobalSettings>
 #include <KMenu>
 #include <KDebug>
@@ -451,6 +451,7 @@ void PersonListEdit::slotAddNamesFromClipboard()
             Value *value = new Value();
             value->append(person);
             lineAdd(value);
+            delete value;
         }
         if (!personList.isEmpty())
             emit modified();
@@ -509,6 +510,7 @@ void UrlListEdit::addReference(const QUrl &url) {
         Value *value = new Value();
         value->append(QSharedPointer<VerbatimText>(new VerbatimText(visibleFilename)));
         lineAdd(value);
+        delete value;
         emit modified();
     }
 }
@@ -518,7 +520,7 @@ void UrlListEdit::slotSaveLocally(QWidget *widget)
     /// Determine FieldLineEdit widget
     FieldLineEdit *fieldLineEdit = qobject_cast<FieldLineEdit *>(widget);
     /// Build Url from line edit's content
-    const KUrl url(fieldLineEdit->text());
+    const KUrl url = KUrl::fromUserInput(fieldLineEdit->text());
 
     /// Only proceed if Url is valid and points to a remote location
     if (url.isValid() && !urlIsLocal(url)) {
@@ -543,18 +545,28 @@ void UrlListEdit::slotSaveLocally(QWidget *widget)
             // FIXME: KIO::NetAccess::download is blocking
             setEnabled(false);
             setCursor(Qt::WaitCursor);
-            if (KIO::NetAccess::file_copy(url, KUrl::fromLocalFile(absoluteFilename), this)) {
-                /// Download succeeded, add reference to local file to this BibTeX entry
-                Value *value = new Value();
-                value->append(QSharedPointer<VerbatimText>(new VerbatimText(visibleFilename)));
-                lineAdd(value);
-            }
-            setEnabled(true);
-            unsetCursor();
+            KIO::CopyJob *job = KIO::copy(url, QUrl::fromLocalFile(absoluteFilename), KIO::Overwrite);
+            job->setProperty("visibleFilename", QVariant::fromValue<QString>(visibleFilename));
+            connect(job, SIGNAL(result(KJob*)), this, SLOT(downloadFinished(KJob*)));
         }
     }
 }
 
+void UrlListEdit::downloadFinished(KJob *j) {
+    KIO::CopyJob *job = static_cast<KIO::CopyJob *>(j);
+    if (job->error() == 0) {
+        /// Download succeeded, add reference to local file to this BibTeX entry
+        Value *value = new Value();
+        value->append(QSharedPointer<VerbatimText>(new VerbatimText(job->property("visibleFilename").toString())));
+        lineAdd(value);
+        delete value;
+    } else {
+        kWarning() << "Downloading" << (*job->srcUrls().constBegin()).pathOrUrl() << "failed with error" << job->error() << job->errorString();
+    }
+    setEnabled(true);
+    unsetCursor();
+}
+
 void UrlListEdit::textChanged(QWidget *widget)
 {
     /// Determine associated KPushButton "Save locally"
@@ -568,16 +580,15 @@ void UrlListEdit::textChanged(QWidget *widget)
     /// Create URL from new text to make some tests on it
     /// Only remote URLs are of interest, therefore no tests
     /// on local file or relative paths
-    QString newText = fieldLineEdit->text();
-    KUrl url(newText);
-    newText = newText.toLower();
+    const QString newText = fieldLineEdit->text();
+    const QString lowerText = newText.toLower();
 
     /// Enable button only if Url is valid and points to a remote
     /// DjVu, PDF, or PostScript file
     // TODO more file types?
-    bool canBeSaved = url.isValid() && !urlIsLocal(url) && (newText.endsWith(QLatin1String(".djvu")) || newText.endsWith(QLatin1String(".pdf")) || newText.endsWith(QLatin1String(".ps")));
+    const bool canBeSaved = lowerText.contains(QLatin1String("://")) && (lowerText.endsWith(QLatin1String(".djvu")) || lowerText.endsWith(QLatin1String(".pdf")) || lowerText.endsWith(QLatin1String(".ps")));
     buttonSaveLocally->setEnabled(canBeSaved);
-    buttonSaveLocally->setToolTip(canBeSaved ? i18n("Save file '%1' locally", url.pathOrUrl()) : QLatin1String(""));
+    buttonSaveLocally->setToolTip(canBeSaved ? i18n("Save file '%1' locally", newText) : QLatin1String(""));
 }
 
 QString UrlListEdit::askRelativeOrStaticFilename(QWidget *parent, const QString &absoluteFilename, const QUrl &baseUrl)
@@ -670,6 +681,7 @@ void KeywordListEdit::slotAddKeywordsFromList()
             Value *value = new Value();
             value->append(QSharedPointer<Keyword>(new Keyword(newKeywordText)));
             lineAdd(value);
+            delete value;
         }
         if (!newKeywordList.isEmpty())
             emit modified();
@@ -688,6 +700,7 @@ void KeywordListEdit::slotAddKeywordsFromClipboard()
             Value *value = new Value();
             value->append(*it);
             lineAdd(value);
+            delete value;
         }
         if (!keywords.isEmpty())
             emit modified();
