@@ -81,7 +81,7 @@ bool SortFilterFileModel::lessThan(const QModelIndex &left, const QModelIndex &r
     int column = left.column();
     Q_ASSERT_X(left.column() == right.column(), "bool SortFilterFileModel::lessThan(const QModelIndex &left, const QModelIndex &right) const", "Not comparing items in same column"); ///< assume that we only sort by column
 
-    BibTeXFields *bibtexFields = BibTeXFields::self();
+    const BibTeXFields *bibtexFields = BibTeXFields::self();
     const FieldDescription *fd = bibtexFields->at(column);
 
     if (column == right.column() && (fd->upperCamelCase == QLatin1String("Author") || fd->upperCamelCase == QLatin1String("Editor"))) {
@@ -162,10 +162,10 @@ bool SortFilterFileModel::filterAcceptsRow(int source_row, const QModelIndex &so
     Q_ASSERT_X(!rowElement.isNull(), "bool SortFilterFileModel::filterAcceptsRow(int source_row, const QModelIndex &source_parent) const", "rowElement is NULL");
 
     /// check if showing comments is disabled
-    if (!m_showComments && typeid(*rowElement) == typeid(Comment))
+    if (!m_showComments && Comment::isComment(*rowElement))
         return false;
     /// check if showing macros is disabled
-    if (!m_showMacros && typeid(*rowElement) == typeid(Macro))
+    if (!m_showMacros && Macro::isMacro(*rowElement))
         return false;
 
     if (m_filterQuery.terms.isEmpty()) return true; /// empty filter query
@@ -208,8 +208,6 @@ bool SortFilterFileModel::filterAcceptsRow(int source_row, const QModelIndex &so
         if (m_filterQuery.searchPDFfiles && m_filterQuery.field.isEmpty()) ///< not filtering for any specific field
             foreach(const KUrl &url, FileInfo::entryUrls(entry.data(), fileSourceModel()->bibliographyFile()->property(File::Url, QUrl()).toUrl(), FileInfo::TestExistenceYes)) {
             if (url.isLocalFile() && url.fileName().endsWith(QLatin1String(".pdf"))) {
-                // FIXME if you have a large collection of PDF files and the text version
-                // has not been generated yet, this will freeze KBibTeX for some time
                 const QString text = FileInfo::pdfToText(url.pathOrUrl());
                 int i = 0;
                 for (QStringList::ConstIterator itsl = m_filterQuery.terms.constBegin(); itsl != m_filterQuery.terms.constEnd(); ++itsl, ++i)
@@ -300,7 +298,7 @@ void FileDelegate::paint(QPainter *painter, const QStyleOptionViewItem &option,
     bool ok = false;
     double percent = index.data(FileModel::NumberRole).toDouble(&ok);
     if (ok) {
-        BibTeXFields *bibtexFields = BibTeXFields::self();
+        const BibTeXFields *bibtexFields = BibTeXFields::self();
         const FieldDescription *fd = bibtexFields->at(index.column());
         if (fd->upperCamelCase.toLower() == Entry::ftStarRating)
             StarRating::paintStars(painter, KIconLoader::DefaultState, numTotalStars, percent, option.rect);
@@ -329,7 +327,9 @@ void FileModel::notificationEvent(int eventId)
     if (eventId == NotificationHub::EventConfigurationChanged) {
         readConfiguration();
         int column = 0;
-        foreach(const FieldDescription *fd, *BibTeXFields::self()) {
+        const BibTeXFields *bf = BibTeXFields::self();
+        for (BibTeXFields::ConstIterator it = bf->constBegin(); it != bf->constEnd(); ++it) {
+            const FieldDescription *fd = *it;
             /// Colors may have changed
             bool columnChanged = fd->upperCamelCase.toLower() == Entry::ftColor;
             /// Person name formatting may has changed
@@ -452,7 +452,7 @@ QVariant FileModel::data(const QModelIndex &index, int role) const
     if (role != NumberRole && role != SortRole && role != Qt::DisplayRole && role != Qt::ToolTipRole && role != Qt::BackgroundRole && role != Qt::ForegroundRole)
         return QVariant();
 
-    BibTeXFields *bibtexFields = BibTeXFields::self();
+    const BibTeXFields *bibtexFields = BibTeXFields::self();
     if (index.row() < m_file->count() && index.column() < bibtexFields->count()) {
         const FieldDescription *fd = bibtexFields->at(index.column());
         QString raw = fd->upperCamelCase;
