@@ -68,8 +68,10 @@ public:
             FieldDescription *fd = new FieldDescription();
 
             fd->upperCamelCase = configGroup.readEntry("UpperCamelCase", QString());
-            if (fd->upperCamelCase.isEmpty())
+            if (fd->upperCamelCase.isEmpty()) {
+                delete fd;
                 continue;
+            }
 
             fd->upperCamelCaseAlt = configGroup.readEntry("UpperCamelCaseAlt", QString());
 
@@ -146,15 +148,12 @@ BibTeXFields::BibTeXFields()
     d->load();
 }
 
-// FIXME destructor seems to crash KBibTeX ...
-/*
 BibTeXFields::~BibTeXFields()
 {
     delete d;
 }
-*/
 
-BibTeXFields *BibTeXFields::self()
+const BibTeXFields *BibTeXFields::self()
 {
     if (BibTeXFieldsPrivate::singleton == NULL)
         BibTeXFieldsPrivate::singleton = new BibTeXFields();
