@@ -441,42 +441,41 @@ static const int mathCommandLen = sizeof(mathCommand) / sizeof(mathCommand[0]);
 static const struct EncoderLaTeXCharacterCommand {
     const char *letters;
     ushort unicode;
-    bool meaningfulCommandName;
 }
 encoderLaTeXCharacterCommands[] = {
-    {"pounds", 0x00A3, false},
-    {"S", 0x00A7, true},
-    {"copyright", 0x00A9, false},
-    {"textregistered", 0x00AE, false},
-    {"textperiodcentered", 0x00B7, false},
-    {"AA", 0x00C5, true},
-    {"AE", 0x00C6, true},
-    {"DH", 0x00D0, true},
-    {"DJ", 0x00D0, true},
-    {"O", 0x00D8, true},
-    {"TH", 0x00DE, true},
-    {"ss", 0x00DF, true},
-    {"aa", 0x00E5, true},
-    {"ae", 0x00E6, true},
-    {"dh", 0x00F0, true},
-    {"o", 0x00F8, true},
-    {"th", 0x00FE, true},
-    {"i", 0x0131, true},
-    {"NG", 0x014A, true},
-    {"ng", 0x014B, true},
-    {"L", 0x0141, true},
-    {"l", 0x0142, true},
-    {"OE", 0x0152, true},
-    {"oe", 0x0153, true},
-    {"j", 0x0237, true},
-    {"ldots", 0x2026, false}, /** \ldots must be before \l */
-    {"grqq", 0x201C, false},
-    {"rqq", 0x201D, false},
-    {"glqq", 0x201E, false},
-    {"frqq", 0x00BB, false},
-    {"flqq", 0x00AB, false},
-    {"rq", 0x2019, false}, ///< tricky one: 'r' is a valid modifier
-    {"lq", 0x2018, false},
+    {"pounds", 0x00A3},
+    {"S", 0x00A7},
+    {"copyright", 0x00A9},
+    {"textregistered", 0x00AE},
+    {"textperiodcentered", 0x00B7},
+    {"AA", 0x00C5},
+    {"AE", 0x00C6},
+    {"DH", 0x00D0},
+    {"DJ", 0x00D0},
+    {"O", 0x00D8},
+    {"TH", 0x00DE},
+    {"ss", 0x00DF},
+    {"aa", 0x00E5},
+    {"ae", 0x00E6},
+    {"dh", 0x00F0},
+    {"o", 0x00F8},
+    {"th", 0x00FE},
+    {"i", 0x0131},
+    {"NG", 0x014A},
+    {"ng", 0x014B},
+    {"L", 0x0141},
+    {"l", 0x0142},
+    {"OE", 0x0152},
+    {"oe", 0x0153},
+    {"j", 0x0237},
+    {"ldots", 0x2026}, /** \ldots must be before \l */
+    {"grqq", 0x201C},
+    {"rqq", 0x201D},
+    {"glqq", 0x201E},
+    {"frqq", 0x00BB},
+    {"flqq", 0x00AB},
+    {"rq", 0x2019}, ///< tricky one: 'r' is a valid modifier
+    {"lq", 0x2018},
 };
 static const int encoderLaTeXCharacterCommandsLen = sizeof(encoderLaTeXCharacterCommands) / sizeof(encoderLaTeXCharacterCommands[0]);
 
@@ -521,6 +520,11 @@ static const int encoderLaTeXSymbolSequencesLen = sizeof(encoderLaTeXSymbolSeque
 
 EncoderLaTeX::EncoderLaTeX()
 {
+    /// Create an ICO Transliterator, configured to
+    /// transliterate virtually anything into plain ASCII
+    UErrorCode uec = U_ZERO_ERROR;
+    m_trans = icu::Transliterator::createInstance("Any-Latin;Latin-ASCII", UTRANS_FORWARD, uec);
+
     /// Initialize lookup table with NULL pointers
     for (int i = 0; i < lookupTableNumModifiers; ++i) lookupTable[i] = NULL;
 
@@ -565,6 +569,9 @@ EncoderLaTeX::~EncoderLaTeX()
     for (int i = lookupTableNumModifiers - 1; i >= 0; --i)
         if (lookupTable[i] != NULL)
             delete lookupTable[i];
+
+    if (m_trans != NULL)
+        delete m_trans;
 }
 
 QString EncoderLaTeX::decode(const QString &input) const
@@ -595,7 +602,7 @@ QString EncoderLaTeX::decode(const QString &input) const
 
                 /// Next, check if there follows a modifier after the backslash
                 /// For example an quotation mark as used in {\"a}
-                int lookupTablePos = modifierInLookupTable(input[i + 2]);
+                int lookupTablePos = modifierInLookupTable(input[i + 2].toLatin1());
 
                 /// Check for spaces between modifier and character, for example
                 /// like {\H o}
@@ -715,7 +722,7 @@ QString EncoderLaTeX::decode(const QString &input) const
 
             /// Check if there follows a modifier after the backslash
             /// For example an quotation mark as used in \"a
-            int lookupTablePos = modifierInLookupTable(input[i + 1]);
+            int lookupTablePos = modifierInLookupTable(input[i + 1].toLatin1());
 
             /// Check for spaces between modifier and character, for example
             /// like \H o
@@ -860,7 +867,13 @@ QString EncoderLaTeX::decode(const QString &input) const
                     /// except for hopping over this backslash
                     if (foundCommand)
                         ++i;
-                    else {
+                    else if (i < len - 1 && input[i + 1] == QChar(0x002c /* comma */)) {
+                        /// Found a thin space: \,
+                        /// Replacing Latex-like thin space with Unicode thin space
+                        output.append(QChar(0x2009));
+                        foundCommand = true;
+                        ++i;
+                    } else {
                         /// Nothing special, copy input char to output
                         output.append(c);
                     }
@@ -1020,6 +1033,12 @@ QString EncoderLaTeX::encode(const QString &ninput) const
                     }
             }
 
+            if (!found && c.unicode() == 0x2009) {
+                /// Thin space
+                output.append(QLatin1String("\\,"));
+                found = true;
+            }
+
             if (!found) {
                 kWarning() << "Don't know how to encode Unicode char" << QString(QLatin1String("0x%1")).arg(c.unicode(), 4, 16, QLatin1Char('0'));
                 output.append(c);
@@ -1061,17 +1080,33 @@ QString EncoderLaTeX::encode(const QString &ninput) const
 
 QString EncoderLaTeX::convertToPlainAscii(const QString &ninput) const
 {
-    /// From iconv's man page:
-    /// If the string //TRANSLIT is appended to to-encoding, characters
-    /// being converted are transliterated when needed and  possible.
-    /// This means that when a character cannot be represented in the
-    /// target character set, it can be approximated through one or
-    /// several similar looking characters.  Characters that are outside
-    /// of the target character set and cannot be transliterated are
-    /// replaced with a question mark (?) in the output.
-    IConvLaTeX iconv(QLatin1String("ascii//translit"));
-    const QByteArray translit = iconv.encode(ninput);
-    return QString(translit);
+    /// Previously, iconv's //TRANSLIT feature had been used here.
+    /// However, the transliteration is locale-specific as discussed
+    /// here:
+    /// http://taschenorakel.de/mathias/2007/11/06/iconv-transliterations/
+    /// Therefore, iconv is not an acceptable solution.
+    ///
+    /// Instead, "International Components for Unicode" (ICU) is used.
+    /// It is already a dependency for Qt, so there is no "cost" involved
+    /// in using it.
+
+    const int ninputLen = ninput.length();
+    /// Make a copy of the input string into an array of UChar
+    UChar *uChars = new UChar[ninputLen];
+    for (int i = 0; i < ninputLen; ++i)
+        uChars[i] = ninput.at(i).unicode();
+    /// Create an ICU-specific unicode string
+    UnicodeString uString = UnicodeString(uChars, ninputLen);
+    /// Perform the actual transliteration, modifying Unicode string
+    m_trans->transliterate(uString);
+    /// Create regular C++ string from Unicode string
+    std::string cppString;
+    uString.toUTF8String(cppString);
+    /// Clean up any mess
+    delete[] uChars;
+    /// Convert regular C++ to Qt-specific QString,
+    /// should work as cppString contains only ASCII text
+    return QString::fromAscii(cppString.c_str());
 }
 
 bool EncoderLaTeX::containsOnlyAscii(const QString &ntext)
@@ -1084,9 +1119,8 @@ bool EncoderLaTeX::containsOnlyAscii(const QString &ntext)
     return true;
 }
 
-int EncoderLaTeX::modifierInLookupTable(const QChar &modifier) const
+int EncoderLaTeX::modifierInLookupTable(const char latinModifier) const
 {
-    const char latinModifier = modifier.toLatin1();
     for (int m = 0; m < lookupTableNumModifiers && lookupTable[m] != NULL; ++m)
         if (lookupTable[m]->modifier == latinModifier) return m;
     return -1;
