@@ -17,8 +17,6 @@
 
 #include "fileimporterbibtex.h"
 
-#include <typeinfo>
-
 #include <QTextCodec>
 #include <QIODevice>
 #include <QRegExp>
@@ -115,7 +113,7 @@ File *FileImporterBibTeX::load(QIODevice *iodevice)
         Element *element = nextElement();
 
         if (element != NULL) {
-            if (!m_ignoreComments || typeid(*element) != typeid(Comment))
+            if (!m_ignoreComments || !Comment::isComment(*element))
                 result->append(QSharedPointer<Element>(element));
             else
                 delete element;
@@ -198,7 +196,7 @@ Element *FileImporterBibTeX::nextElement()
     } else if (token == tUnknown) {
         kDebug() << "Unknown token '" << m_nextChar << "(" << QString(QLatin1String("0x%1")).arg(m_nextChar.unicode(), 4, 16, QLatin1Char('0')) << ")" << "' near line " << m_lineNo << "(" << m_prevLine << endl << m_currentLine << ")" << ", treating as comment";
         ++m_statistics.countNoCommentQuote;
-        return readPlainCommentElement();
+        return readPlainCommentElement(QString(m_prevChar) + m_nextChar);
     }
 
     if (token != tEOF)
@@ -214,11 +212,15 @@ Comment *FileImporterBibTeX::readCommentElement()
     return new Comment(EncoderLaTeX::instance()->decode(readBracketString()));
 }
 
-Comment *FileImporterBibTeX::readPlainCommentElement()
+Comment *FileImporterBibTeX::readPlainCommentElement(const QString &prefix)
 {
-    QString result = EncoderLaTeX::instance()->decode(readLine());
+    QString result = EncoderLaTeX::instance()->decode(prefix + readLine());
+    while (m_nextChar == QLatin1Char('\n') || m_nextChar == QLatin1Char('\r')) readChar();
     while (!m_nextChar.isNull() && m_nextChar != QLatin1Char('@')) {
-        result.append(QLatin1String("\n")).append(EncoderLaTeX::instance()->decode(readLine()));
+        const QChar nextChar = m_nextChar;
+        const QString line = readLine();
+        while (m_nextChar == QLatin1Char('\n') || m_nextChar == QLatin1Char('\r')) readChar();
+        result.append(EncoderLaTeX::instance()->decode((nextChar == QLatin1Char('%') ? QString() : QString(nextChar)) + line));
     }
 
     if (result.startsWith(QLatin1String("x-kbibtex"))) {
@@ -317,8 +319,8 @@ Preamble *FileImporterBibTeX::readPreambleElement()
 
 Entry *FileImporterBibTeX::readEntryElement(const QString &typeString)
 {
-    BibTeXEntries *be = BibTeXEntries::self();
-    BibTeXFields *bf = BibTeXFields::self();
+    const BibTeXEntries *be = BibTeXEntries::self();
+    const BibTeXFields *bf = BibTeXFields::self();
     EncoderLaTeX *encoder = EncoderLaTeX::instance();
 
     Token token = nextToken();
@@ -330,7 +332,7 @@ Entry *FileImporterBibTeX::readEntryElement(const QString &typeString)
         token = nextToken();
     }
 
-    QString id = readSimpleString(QChar(',')).trimmed();
+    QString id = readSimpleString(',').trimmed();
     if (id.isEmpty()) {
         /// Cope with empty ids,
         /// duplicates are handled further below
@@ -503,7 +505,7 @@ QString FileImporterBibTeX::readString(bool &isStringKey)
     }
 }
 
-QString FileImporterBibTeX::readSimpleString(const QChar &until)
+QString FileImporterBibTeX::readSimpleString(const char until)
 {
     const QString extraAlphaNumChars = QLatin1String("?'`-_:.+/$\\\"&");
 
@@ -517,7 +519,7 @@ QString FileImporterBibTeX::readSimpleString(const QChar &until)
     while (!m_nextChar.isNull()) {
         if (until != '\0') {
             /// Variable "until" has user-defined value
-            if (m_nextChar == QLatin1Char('\n') || m_nextChar == QLatin1Char('\r') || m_nextChar == until) {
+            if (m_nextChar == QLatin1Char('\n') || m_nextChar == QLatin1Char('\r') || m_nextChar.toLatin1() == until) {
                 /// Force break on line-breaks or if the "until" char has been read
                 break;
             } else {
@@ -776,7 +778,6 @@ QString FileImporterBibTeX::readLine()
     QString result;
     while (m_nextChar != QLatin1Char('\n') && m_nextChar != QLatin1Char('\r') && readChar())
         result.append(m_nextChar);
-    if (!readChar()) return QString();
     return result;
 }
 
