@@ -20,7 +20,6 @@
 #include <QNetworkReply>
 #include <QNetworkRequest>
 #include <QRegExp>
-#include <QTextStream>
 
 #include <poppler-qt4.h>
 
@@ -84,7 +83,7 @@ public:
         if (!ok) depth = 0;
 
         /// regular expressions to guess links to follow
-        const QRegExp anchorRegExp[5] = {
+        static const QRegExp anchorRegExp[5] = {
             QRegExp(QString(QLatin1String("<a[^>]*href=\"([^\"]*%1[^\"]*[.]pdf)\"")).arg(QRegExp::escape(term)), Qt::CaseInsensitive),
             QRegExp(QString(QLatin1String("<a[^>]*href=\"([^\"]+)\"[^>]*>[^<]*%1[^<]*[.]pdf")).arg(QRegExp::escape(term)), Qt::CaseInsensitive),
             QRegExp(QString(QLatin1String("<a[^>]*href=\"([^\"]*%1[^\"]*)\"")).arg(QRegExp::escape(term)), Qt::CaseInsensitive),
@@ -130,8 +129,9 @@ public:
                 int p1 = p + 6;
                 int p2 = text.indexOf(QLatin1Char('"'), p1 + 1);
                 QUrl url(text.mid(p1, p2 - p1));
-                kDebug() << "Google URL" << i << " : " << url.toString();
-                queueUrl(reply->url().resolved(url), term, QLatin1String("scholar.google"), depth - 1);
+                const QString googleService = reply->url().host().contains(QLatin1String("scholar.google")) ? QLatin1String("scholar.google") : QLatin1String("www.google");
+                kDebug() << "Google URL" << i << " : " << url.toString() << "(" << googleService << ")";
+                queueUrl(reply->url().resolved(url), term, googleService, depth - 1);
             }
         }
     }
@@ -196,10 +196,11 @@ public:
             const int maxTextLen = 1024;
             for (int i = 0; i < doc->numPages() && resultItem.textPreview.length() < maxTextLen; ++i) {
                 Poppler::Page *page = doc->page(i);
-                resultItem.textPreview += QLatin1Char(' ');
+                if (!resultItem.textPreview.isEmpty()) resultItem.textPreview += QLatin1Char(' ');
                 resultItem.textPreview += page->text(QRect()).simplified().leftRef(maxTextLen);
                 delete page;
             }
+            resultItem.textPreview.remove(QLatin1String("Microsoft Word - ")); ///< Some word processors need to put their name everywhere ...
             resultItem.downloadMode = NoDownload;
             resultItem.relevance = origin == Entry::ftDOI ? 1.0 : (origin == QLatin1String("eprint") ? 0.75 : 0.5);
             result << resultItem;
@@ -217,6 +218,11 @@ FindPDF::FindPDF(QObject *parent)
     /// nothing
 }
 
+FindPDF::~FindPDF()
+{
+    delete d;
+}
+
 bool FindPDF::search(const Entry &entry)
 {
     if (d->aliveCounter > 0) return false;
@@ -245,7 +251,7 @@ bool FindPDF::search(const Entry &entry)
     QStringList urlFields = QStringList() << Entry::ftDOI << Entry::ftUrl << QLatin1String("ee");
     for (int i = 2; i < 256; ++i)
         urlFields << QString(QLatin1String("%1%2")).arg(Entry::ftDOI).arg(i) << QString(QLatin1String("%1%2")).arg(Entry::ftUrl).arg(i);
-    foreach(const QString &field, urlFields) {
+    foreach (const QString &field, urlFields) {
         if (entry.contains(field)) {
             const QString fieldText = PlainTextValue::text(entry.value(field));
             int p = -1;
@@ -262,29 +268,43 @@ bool FindPDF::search(const Entry &entry)
         /// check eprint fields as used for arXiv
         const QString fieldText = PlainTextValue::text(entry.value(QLatin1String("eprint")));
         if (!fieldText.isEmpty())
-            d->queueUrl(QUrl(QLatin1String("http://arxiv.org/pdf/") + fieldText), fieldText, QLatin1String("eprint"), maxDepth);
+            d->queueUrl(QUrl(QString(QLatin1String("http://arxiv.org/find/all/1/all:+%1/0/1/0/all/0/1")).arg(fieldText)), fieldText, QLatin1String("eprint"), maxDepth);
     }
 
     if (!searchWords.isEmpty()) {
-        /// use title to search in Google Scholar
+        /// Search in Google
+        KUrl googleUrl(QLatin1String("https://www.google.com/search?hl=en&sa=G"));
+        googleUrl.addQueryItem(QLatin1String("q"), searchWords + QLatin1String(" filetype:pdf"));
+        d->queueUrl(googleUrl, searchWords, QLatin1String("www.google"), maxDepth);
+
+        /// Search in Google Scholar
         KUrl googleScholarUrl(QLatin1String("http://scholar.google.com/scholar?hl=en&btnG=Search&as_sdt=1"));
         googleScholarUrl.addQueryItem(QLatin1String("q"), searchWords + QLatin1String(" filetype:pdf"));
         d->queueUrl(googleScholarUrl, searchWords, QLatin1String("scholar.google"), maxDepth);
 
-        /// use title to search in Bing
-        KUrl bingUrl(QLatin1String("http://www.bing.com/search?setmkt=en-IE&setlang=match"));
+        /// Search in Bing
+        KUrl bingUrl(QLatin1String("https://www.bing.com/search?setlang=en-US"));
         bingUrl.addQueryItem(QLatin1String("q"), searchWords + QLatin1String(" filetype:pdf"));
         d->queueUrl(bingUrl, searchWords, QLatin1String("bing"), maxDepth);
 
-        /// use title to search in Microsoft Academic Search
+        /// Search in Microsoft Academic Search
         KUrl masUrl(QLatin1String("http://academic.research.microsoft.com/Search"));
         masUrl.addQueryItem(QLatin1String("query"), searchWords);
         d->queueUrl(masUrl, searchWords, QLatin1String("academicsearch"), maxDepth);
 
-        /// use title to search in CiteSeerX
+        /// Search in CiteSeerX
         KUrl citeseerXurl(QLatin1String("http://citeseerx.ist.psu.edu/search?submit=Search&sort=rlv&t=doc"));
         citeseerXurl.addQueryItem(QLatin1String("q"), searchWords);
         d->queueUrl(citeseerXurl, searchWords, QLatin1String("citeseerx"), maxDepth);
+
+        /// Search in StartPage
+        KUrl startPageUrl(QLatin1String("https://www.startpage.com/do/asearch?cat=web&cmd=process_search&language=english&engine0=v1all&abp=-1&t=white&nj=1&prf=23ad6aab054a88d3da5c443280cee596&suggestOn=0"));
+        startPageUrl.addQueryItem(QLatin1String("query"), searchWords + QLatin1String(" filetype:pdf"));
+        d->queueUrl(startPageUrl, searchWords, QLatin1String("startpage"), maxDepth);
+
+        /// Search in arXiv
+        KUrl arXivUrl = KUrl::fromUserInput(QString(QLatin1String("http://arxiv.org/find/all/1/all:+%1/0/1/0/all/0/1")).arg(searchWords));
+        d->queueUrl(arXivUrl, searchWords, QLatin1String("arxiv"), maxDepth);
     }
 
     if (d->aliveCounter == 0) {
@@ -321,25 +341,28 @@ void FindPDF::downloadFinished()
     if (!depthOk) depth = 0;
 
     if (reply->error() == QNetworkReply::NoError) {
-        QByteArray data = reply->readAll();
+        const QByteArray data = reply->readAll();
 
-        QUrl redirUrl = reply->url().resolved(reply->attribute(QNetworkRequest::RedirectionTargetAttribute).toUrl());
+        QUrl redirUrl = reply->attribute(QNetworkRequest::RedirectionTargetAttribute).toUrl();
+        redirUrl = redirUrl.isEmpty() ? QUrl() : reply->url().resolved(redirUrl);
         kDebug() << "finished Downloading " << reply->url().toString() << "   depth=" << depth  << "  d->aliveCounter=" << d->aliveCounter << "  data.size=" << data.size() << "  redirUrl=" << redirUrl.toString() << "   origin=" << origin;
 
-        if (data.contains(htmlHead1) || data.contains(htmlHead2)) {
+        if (!redirUrl.isEmpty())
+            d->queueUrl(redirUrl, term, origin, depth - 1);
+        else if (data.contains(htmlHead1) || data.contains(htmlHead2)) {
             /// returned data is a HTML file, i.e. contains "<html"
 
             /// check for limited depth before continuing
             if (depthOk && depth > 0) {
-                /// get webpage as plain text
-                QTextStream ts(data);
-                const QString text = ts.readAll();
+                /// Get webpage as plain text
+                /// Assume UTF-8 data
+                const QString text = QString::fromUtf8(data.constData());
 
                 /// regular expression to check if this is a Google Scholar result page
                 static const QRegExp googleScholarTitleRegExp(QLatin1String("<title>[^>]* - Google Scholar</title>"));
                 /// regular expression to check if this is a SpringerLink page
-                static const QRegExp springerLinkTitleRegExp(QLatin1String("<title>[^>]*SpringerLink - [^>]*</title>"));
-                /// regular expression to check if this is a SpringerLink page
+                static const QRegExp springerLinkTitleRegExp(QLatin1String("<title>[^>]* - Springer - [^>]*</title>"));
+                /// regular expression to check if this is a CiteSeerX page
                 static const QRegExp citeseerxTitleRegExp(QLatin1String("<title>CiteSeerX &mdash; [^>]*</title>"));
 
                 if (text.indexOf(googleScholarTitleRegExp) > 0)
@@ -348,27 +371,32 @@ void FindPDF::downloadFinished()
                     d->processSpringerLink(reply, text);
                 else if (text.indexOf(citeseerxTitleRegExp) > 0)
                     d->processCiteSeerX(reply, text);
-                else
+                else {
+                    /// regular expression to extract title
+                    static QRegExp titleRegExp(QLatin1String("<title>(.*)</title>"));
+                    titleRegExp.setMinimal(true);
+                    if (titleRegExp.indexIn(text) >= 0)
+                        kDebug() << "Using general HTML processor for page" << titleRegExp.cap(1) << " URL=" << reply->url().toString();
+                    else
+                        kDebug() << "Using general HTML processor for URL=" << reply->url().toString();
                     d->processGeneralHTML(reply, text);
+                }
             }
         } else if (data.contains(pdfHead)) {
             /// looks like a PDF file -> grab it
             const bool gotPDFfile = d->processPDF(reply, data);
             if (gotPDFfile)
                 emit progress(d->knownUrls.count(), d->aliveCounter, d->result.count());
-        } else if (redirUrl.isValid())
-            d->queueUrl(redirUrl, term, origin, depth - 1);
-        else {
-            QTextStream ts(data);
-            const QString text = ts.readAll();
+        } else {
+            /// Assume UTF-8 data
+            const QString text = QString::fromUtf8(data.constData());
             kDebug() << "don't know how to handle " << text.left(256);
         }
     } else
-        kDebug() << "error from reply: " << reply->errorString();
+        kWarning() << "error from reply: " << reply->errorString() << "(" << reply->url().toString() << ")" << "  term=" << term << "  origin=" << origin << "  depth=" << depth;
 
     if (d->aliveCounter == 0) {
         /// no more running downloads left
         emit finished();
     }
 }
-
