@@ -17,6 +17,9 @@
 
 #include "api.h"
 
+#include <QDateTime>
+#include <QTimer>
+
 #include <KUrl>
 #include <KDebug>
 
@@ -29,14 +32,16 @@ private:
 
 public:
     const KUrl apiBaseUrl;
+    const int userOrGroupPrefix;
     const QString apiKey;
-    int userOrGroupPrefix;
+
+    QDateTime backoffElapseTime;
 
     Private(RequestScope requestScope, int prefix, const QString &_apiKey, Zotero::API */* UNUSED parent*/)
         : // UNUSED p(parent),
         apiBaseUrl(KUrl(QString(QLatin1String("https://api.zotero.org/%1/%2%3")).arg(requestScope == GroupRequest ? QLatin1String("groups") : QLatin1String("users")).arg(prefix).arg(_apiKey.isEmpty() ? QString() : QString(QLatin1String("?key=%1")).arg(_apiKey)))),
-        apiKey(_apiKey),
-        userOrGroupPrefix(prefix) {
+        userOrGroupPrefix(prefix),
+        apiKey(_apiKey), backoffElapseTime(QDateTime::currentDateTime().addSecs(-5)) {
         /// nothing
     }
 };
@@ -63,10 +68,10 @@ void API::addLimitToUrl(KUrl &url) const
 
 void API::addKeyToUrl(KUrl &url) const
 {
-    if (!d->apiKey.isEmpty()){
-    static const QString keyKey = QLatin1String("key");
-    url.removeQueryItem(keyKey);
-    url.addQueryItem(keyKey, d->apiKey);
+    if (!d->apiKey.isEmpty()) {
+        static const QString keyKey = QLatin1String("key");
+        url.removeQueryItem(keyKey);
+        url.addQueryItem(keyKey, d->apiKey);
     }
 }
 
@@ -82,8 +87,35 @@ int API::userOrGroupPrefix() const
 
 QNetworkRequest API::request(const KUrl &url) const
 {
-    kDebug() << "url=" << url.pathOrUrl();
     QNetworkRequest request(url);
-    request.setRawHeader("Zotero-API-Version", "2");
+    request.setRawHeader("Zotero-API-Version", "3");
+    request.setRawHeader("Accept", "application/atom+xml");
+    request.setRawHeader("Authorization", QString(QLatin1String("Bearer ")).append(d->apiKey).toAscii().constData());
     return request;
 }
+
+void API::startBackoff(int duration) {
+    if (duration > 0 && !inBackoffMode()) {
+        d->backoffElapseTime = QDateTime::currentDateTime().addSecs(duration + 1);
+        emit backoffModeStart();
+        /// Use single-shot timer and functor to emit signal
+        /// that backoff mode has finished
+        QTimer::singleShot((duration + 1) * 1000, this, SLOT(startBackoffSingleShot()));
+    }
+}
+
+void API::startBackoffSingleShot() {
+    emit backoffModeEnd();
+}
+
+bool API::inBackoffMode() const {
+    return d->backoffElapseTime >= QDateTime::currentDateTime();
+}
+
+qint64 API::backoffSecondsLeft() const {
+    const qint64 diff = QDateTime::currentDateTime().secsTo(d->backoffElapseTime);
+    if (diff < 0)
+        return 0;
+    else
+        return diff;
+}
