@@ -22,6 +22,7 @@
 #include <QVector>
 #include <QNetworkReply>
 #include <QXmlStreamReader>
+#include <QTimer>
 
 #include <KDebug>
 #include <KLocale>
@@ -36,10 +37,12 @@ class Zotero::Collection::Private
 {
 private:
     Zotero::Collection *p;
-    QSharedPointer<Zotero::API> api;
 
 public:
+    QSharedPointer<Zotero::API> api;
+
     static const QString top;
+    KUrl queuedRequestZoteroUrl;
 
     Private(QSharedPointer<Zotero::API> a, Zotero::Collection *parent)
             : p(parent), api(a) {
@@ -71,10 +74,14 @@ public:
             const QString head = downloadQueue.dequeue();
             KUrl url = api->baseUrl();
             url.addPath(QString(QLatin1String("/collections/%1/collections")).arg(head));
-            requestZoteroUrl(url);
+            if (api->inBackoffMode() && queuedRequestZoteroUrl.isEmpty()) {
+                /// If Zotero asked to 'back off', wait until this period is over before issuing the next request
+                queuedRequestZoteroUrl = url;
+                QTimer::singleShot((api->backoffSecondsLeft() + 1) * 1000, p, SLOT(singleShotRequestZoteroUrl()));
+            } else
+                requestZoteroUrl(url);
         } else {
             initialized = true;
-            kDebug() << "Queue is empty, number of found collections:" << collectionToLabel.count();
             p->emitFinishedLoading();
         }
     }
@@ -89,7 +96,17 @@ Collection::Collection(QSharedPointer<Zotero::API> api, QObject *parent)
 
     KUrl url = api->baseUrl();
     url.addPath(QLatin1String("/collections/top"));
-    d->requestZoteroUrl(url);
+    if (api->inBackoffMode() && d->queuedRequestZoteroUrl.isEmpty()) {
+        /// If Zotero asked to 'back off', wait until this period is over before issuing the next request
+        d->queuedRequestZoteroUrl = url;
+        QTimer::singleShot((api->backoffSecondsLeft() + 1) * 1000, this, SLOT(singleShotRequestZoteroUrl()));
+    } else
+        d->requestZoteroUrl(url);
+}
+
+Collection::~Collection()
+{
+    delete d;
 }
 
 bool Collection::initialized() const
@@ -152,6 +169,18 @@ void Collection::finishedFetchingCollection()
     QNetworkReply *reply = static_cast<QNetworkReply *>(sender());
     QString parentId = Private::top;
 
+    if (reply->hasRawHeader("Backoff")) {
+        bool ok = false;
+        int time = QString::fromLatin1(reply->rawHeader("Backoff").constData()).toInt(&ok);
+        if (!ok) time = 10; ///< parsing argument of raw header 'Backoff' failed? 10 seconds is fallback
+        d->api->startBackoff(time);
+    } else if (reply->hasRawHeader("Retry-After")) {
+        bool ok = false;
+        int time = QString::fromLatin1(reply->rawHeader("Retry-After").constData()).toInt(&ok);
+        if (!ok) time = 10; ///< parsing argument of raw header 'Retry-After' failed? 10 seconds is fallback
+        d->api->startBackoff(time);
+    }
+
     if (reply->error() == QNetworkReply::NoError) {
         QString nextPage;
         QXmlStreamReader xmlReader(reply);
@@ -198,7 +227,12 @@ void Collection::finishedFetchingCollection()
         }
 
         if (!nextPage.isEmpty()) {
-            d->requestZoteroUrl(nextPage);
+            if (d->api->inBackoffMode() && d->queuedRequestZoteroUrl.isEmpty()) {
+                /// If Zotero asked to 'back off', wait until this period is over before issuing the next request
+                d->queuedRequestZoteroUrl = nextPage;
+                QTimer::singleShot((d->api->backoffSecondsLeft() + 1) * 1000, this, SLOT(singleShotRequestZoteroUrl()));
+            } else
+                d->requestZoteroUrl(nextPage);
         } else
             d->runNextInDownloadQueue();
     } else {
@@ -213,3 +247,8 @@ void Collection::emitFinishedLoading()
     d->busy = false;
     emit finishedLoading();
 }
+
+void Collection::singleShotRequestZoteroUrl() {
+    d->requestZoteroUrl(d->queuedRequestZoteroUrl);
+    d->queuedRequestZoteroUrl.clear();
+}
