@@ -54,8 +54,8 @@ public:
     /// Key to store/retrieve setting whether changes in form should be automatically applied to element or not
     static const QString configKeyAutoApply;
 
-    ElementFormPrivate(ElementForm *parent)
-            : p(parent), file(NULL), gotModified(false), config(KSharedConfig::openConfig(QLatin1String("kbibtexrc"))) {
+    ElementFormPrivate(MDIWidget *_mdiWidget, ElementForm *parent)
+            : p(parent), file(NULL), mdiWidget(_mdiWidget), gotModified(false), config(KSharedConfig::openConfig(QLatin1String("kbibtexrc"))) {
         KConfigGroup configGroup(config, configGroupName);
 
         layout = new QGridLayout(p);
@@ -162,10 +162,9 @@ const QString ElementForm::ElementFormPrivate::configGroupName = QLatin1String("
 const QString ElementForm::ElementFormPrivate::configKeyAutoApply = QLatin1String("AutoApply");
 
 ElementForm::ElementForm(MDIWidget *mdiWidget, QDockWidget *parent)
-        : QWidget(parent), d(new ElementFormPrivate(this))
+        : QWidget(parent), d(new ElementFormPrivate(mdiWidget, this))
 {
     connect(parent, SIGNAL(visibilityChanged(bool)), this, SLOT(visibilityChanged(bool)));
-    d->mdiWidget = mdiWidget;
 }
 
 ElementForm::~ElementForm()
