@@ -67,6 +67,7 @@
 #include "onlinesearchisbndb.h"
 #include "onlinesearchideasrepec.h"
 #include "onlinesearchdoi.h"
+#include "onlinesearchbiorxiv.h"
 #include "openfileinfo.h"
 #include "fileview.h"
 #include "filemodel.h"
@@ -215,6 +216,7 @@ public:
 
         addEngine(new OnlineSearchAcmPortal(p));
         addEngine(new OnlineSearchArXiv(p));
+        addEngine(new OnlineSearchBioRxiv(p));
         addEngine(new OnlineSearchBibsonomy(p));
         addEngine(new OnlineSearchGoogleScholar(p));
         addEngine(new OnlineSearchIEEEXplore(p));
