@@ -189,6 +189,7 @@ KBibTeXMainWindow::KBibTeXMainWindow(QWidget *parent)
     d->dockZotero->setAllowedAreas(Qt::BottomDockWidgetArea | Qt::TopDockWidgetArea | Qt::LeftDockWidgetArea | Qt::RightDockWidgetArea);
     addDockWidget(Qt::LeftDockWidgetArea, d->dockZotero);
     d->zotero = new ZoteroBrowser(d->searchResults, d->dockZotero);
+    connect(d->dockZotero, SIGNAL(visibilityChanged(bool)), d->zotero, SLOT(visibiltyChanged(bool)));
     connect(d->zotero, SIGNAL(itemToShow()), this, SLOT(showSearchResults()));
     d->dockZotero->setWidget(d->zotero);
     d->dockZotero->setObjectName("dockZotero");
@@ -318,7 +319,7 @@ void KBibTeXMainWindow::openDocumentDialog()
 {
     OpenFileInfo *currFile = d->mdiWidget->getOpenFileInfoManager()->currentFile();
     KUrl currFileUrl = currFile == NULL ? KUrl() : currFile->url();
-    QString startDir = currFileUrl.isValid() ? KUrl(currFileUrl.url()).path() : QLatin1String("kfiledialog:///opensave");
+    QString startDir = currFileUrl.isValid() ? KUrl(currFileUrl.url()).path() : QString();
     OpenFileInfo *ofi = d->mdiWidget->getOpenFileInfoManager()->currentFile();
     if (ofi != NULL) {
         KUrl url = ofi->url();
