@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2004-2014 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
+ *   Copyright (C) 2004-2017 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -25,13 +25,13 @@
 #include "version.h"
 
 const char *description = I18N_NOOP("A BibTeX editor for KDE");
-const char *programHomepage = "http://home.gna.org/kbibtex/";
+const char *programHomepage = "https://userbase.kde.org/KBibTeX";
 
 int main(int argc, char *argv[])
 {
     KAboutData aboutData("kbibtex", 0, ki18n("KBibTeX"), versionNumber,
                          ki18n(description), KAboutData::License_GPL_V2,
-                         ki18n("Copyright 2004-2014 Thomas Fischer"), KLocalizedString(),
+                         ki18n("Copyright 2004-2017 Thomas Fischer"), KLocalizedString(),
                          programHomepage);
     aboutData.addAuthor(ki18n("Thomas Fischer"), ki18n("Maintainer"), "fischer@unix-ag.uni-kl.de", "http://www.t-fischer.net/");
 
@@ -45,8 +45,19 @@ int main(int argc, char *argv[])
     kDebug() << "Starting KBibTeX version" << versionNumber;
 
     KService::Ptr service = KService::serviceByStorageId("kbibtexpart.desktop");
-    if (service.isNull())
+    if (service.isNull()) {
+        /// Dump some environment variables that may be helpful
+        /// in tracing back why the part's .desktop file was not found
+        kDebug() << "PATH=" << getenv("PATH");
+        kDebug() << "LD_LIBRARY_PATH=" << getenv("LD_LIBRARY_PATH");
+        kDebug() << "XDG_DATA_DIRS=" << getenv("XDG_DATA_DIRS");
+        kDebug() << "QT_PLUGIN_PATH=" << getenv("QT_PLUGIN_PATH");
+        kDebug() << "KDEDIRS=" << getenv("KDEDIRS");
         KMessageBox::error(NULL, i18n("KBibTeX seems to be not installed completely. KBibTeX could not locate its own KPart.\n\nOnly limited functionality will be available."), i18n("Incomplete KBibTeX Installation"));
+    } else {
+        kDebug() << "Located KPart service:" << service->library() << "with description" << service->comment();
+    }
+
 
     /// started by session management?
     if (programCore.isSessionRestored()) {
@@ -69,5 +80,3 @@ int main(int argc, char *argv[])
 
     return programCore.exec();
 }
-
-
